@@ -6,8 +6,10 @@ import pltrdy.pickle
 import pltrdy.rouge
 import pltrdy.stats
 import pltrdy.time
+import pltrdy.tee
 import pltrdy.wc  # noqa F401
 
 from pltrdy.describe import describe_str, describe_lines, describe, tab_print
+from pltrdy.reload import reload_class
 
-__version__ = "0.2"
+__version__ = "0.2.2"
